@@ -5,7 +5,9 @@
 #include "except.hpp"
 
 class Key;
+class Hash;
 class CryptIter;
+class Cert;
 
 class CryptDesc
 {
@@ -36,10 +38,12 @@ class Crypt : public RCObj
     HCRYPTPROV hprov;
     char *cont_name;
     char *pr_name;
+    Cert *parent;
 
 public:
 
-    Crypt (char *container, DWORD type, DWORD flags, char *name=NULL) throw(CSPException, CSPNotFound);
+    Crypt (BYTE *STRING, DWORD LENGTH, DWORD type, DWORD flags, char *name=NULL) throw(CSPException, CSPNotFound);
+    Crypt (Cert *pcert) throw(CSPNotFound);
     ~Crypt() throw(CSPException);
 
     char *name();
@@ -61,6 +65,7 @@ public:
     static CryptIter *enumerate() throw(CSPException);
 
     friend class Cert;
+    friend class Hash;
     friend class CryptMsg;
     friend class Signature;
     friend class CertStore;
