@@ -1,5 +1,6 @@
 #include "common.hpp"
 #include "context.hpp"
+#include "cert.hpp"
 #include "key.hpp"
 
 Crypt::~Crypt() throw(CSPException) {
@@ -21,6 +22,9 @@ Crypt::~Crypt() throw(CSPException) {
         LOG("freeing pr_name(%p)\n", pr_name);
         delete[] pr_name;
     }
+    if(parent) {
+        parent->unref();
+    }
     LOG("    Freed ctx %p (%x)\n", this, hprov);
 }
 
@@ -111,13 +115,15 @@ void Crypt::change_password(char *pin) throw (CSPException) {
     }
 }
 
-Crypt::Crypt(char *container, DWORD type, DWORD flags, char *name) throw(CSPException, CSPNotFound)
+Crypt::Crypt (BYTE *STRING, DWORD LENGTH, DWORD type, DWORD flags, char *name) throw(CSPException, CSPNotFound)
 {
     LOG("Crypt::Crypt(%s, %u, %x, %s)\n", container, type, flags, name);
     cont_name = NULL;
-    if (container) {
-        cont_name = new char[strlen(container) + 1];
-        strcpy(cont_name, container);
+    parent = NULL;
+    if (STRING) {
+        cont_name = new char[LENGTH + 1];
+        strncpy(cont_name, (const char *)STRING, LENGTH);
+        cont_name[LENGTH] = 0;
     }
  
     pr_name = NULL;
@@ -144,6 +150,27 @@ Crypt::Crypt(char *container, DWORD type, DWORD flags, char *name) throw(CSPExce
     }
 }
 
+Crypt::Crypt (Cert *pcert) throw(CSPNotFound)
+{
+    LOG("Crypt::Crypt(%x)\n", parent);
+    DWORD dwKeySpec; // XXX: not used
+    cont_name = NULL;
+    pr_name = NULL;
+    parent = pcert;
+    parent->ref();
+
+    if(!(CryptAcquireCertificatePrivateKey(
+            parent->pcert,
+            0,
+            NULL,
+            &hprov,
+            &dwKeySpec,
+            NULL)))
+    {
+        throw CSPNotFound("Crypt: Couldn't acquire certificate private key");
+    }
+}
+
 Key *Crypt::get_key(DWORD keyspec) throw(CSPException, CSPNotFound)
 {
     HCRYPTKEY hkey = 0;
